@@ -1,12 +1,7 @@
-/* 05apr22 Software Lab. Alexander Burger */
-
-var FormReq = new XMLHttpRequest();
-FormReq.upload.addEventListener("progress", dropProgress, false);
-FormReq.upload.addEventListener("load", dropLoad, false);
+/* 05oct23 Software Lab. Alexander Burger */
 
 var Btn = [];
-var Queue = [];
-var Busy, SesId, Key, InBtn, Auto, Chg, Post, Drop, Hint, Hints, Item, Beg, End;
+var SesId, Key, InBtn, Auto, Chg, Post, Drop, Hint, Hints, Item, Beg, End;
 
 function inBtn(btn,flg) {InBtn = flg;}
 
@@ -112,27 +107,24 @@ function doPost(form) {
 
 function post(form, auto, exe, file) {
    var i, data;
+   var req = new XMLHttpRequest();
 
-   if (!FormReq || !hasElement(form,"*Get") || (i = form.action.indexOf("~")) <= 0)
+   if (!hasElement(form,"*Form") || (i = form.action.indexOf("~")) <= 0)
       return true;
-   if (Busy) {
-      Queue.push([form, auto, exe, file]);
-      return false;
-   }
-   Busy = true;
    form.style.cursor = "wait";
-   try {FormReq.open("POST", SesId + "!jsForm?" + form.action.substr(i+1));}
+   try {req.open("POST", SesId + "!jsForm?" + form.action.substr(i+1));}
    catch (e) {return true;}
-   FormReq.onload = function() {
-      if (FormReq.responseText == "T") {
-         Queue.length = 0;
+   req.onload = function() {
+      if (req.status != 200)
+         req.abort();
+      else if (req.responseText == "T")
          form.submit();
-      }
-      else {
-         var txt = FormReq.responseText.split("&");
+      else if (req.responseText) {
+         var txt = req.responseText.split("&");
 
-         if (txt[0]) {
-            var r = txt[0].split(":");
+         form.elements["*Evt"].value = txt[0];
+         if (txt[1]) {
+            var r = txt[1].split(":");
 
             if (Auto)
                clearTimeout(Auto);
@@ -152,7 +144,7 @@ function post(form, auto, exe, file) {
          if (!auto || !Chg) {
             var i, j;
 
-            for (i = 1; i < txt.length;) {
+            for (i = 2; i < txt.length;) {
                var fld = txt[i++];
                var val = decodeURIComponent(txt[i++]);
 
@@ -260,7 +252,12 @@ function post(form, auto, exe, file) {
                   switch (j) {
 
                   case 0:  // '#'
-                     fld.setAttribute("class", txt[i++].substr(1));
+                     var cls;
+
+                     val = txt[i++].substr(1);
+                     if ((cls = fld.getAttribute("class")) != null  &&  (j = cls.indexOf("  ")) >= 0)
+                        val += cls.substr(j);
+                     fld.setAttribute("class", val);
                      break;
 
                   case 1:  // '*'
@@ -294,12 +291,7 @@ function post(form, auto, exe, file) {
             Chg = false;
          }
       }
-      Busy = false;
       form.style.cursor = "";
-      if (Queue.length > 0) {
-         var a = Queue.shift();
-         post(a[0], a[1], a[2], a[3]);
-      }
    };
    if (!exe)
       data = "";
@@ -334,20 +326,23 @@ function post(form, auto, exe, file) {
    }
    try {
       if (!file)
-         FormReq.send(data);
+         req.send(data);
       else {
          var rd = new FileReader();
+
+         req.upload.addEventListener("progress", dropProgress, false);
+         req.upload.addEventListener("load", dropLoad, false);
          rd.readAsBinaryString(file);
          rd.onload = function() {
-            FormReq.setRequestHeader("X-Pil", "*ContL=T");
-            FormReq.sendAsBinary(data + "&*Drop=" +
+            req.setRequestHeader("X-Pil", "*ContL=T");
+            req.sendAsBinary(data + "&*Drop=" +
                encodeURIComponent(file.name) + "=" +
                file.size + "\n" + rd.result );
          }
       }
    }
    catch (e) {
-      FormReq.abort();
+      req.abort();
       return true;
    }
    return false;
